Obtain information about the bins from a tidyvpcobj
Usage
bininfo(o, ...)
# S3 method for class 'tidyvpcobj'
bininfo(o, by.strata = o$bin.by.strata, ...)Value
A `data.table` containing the following columns:
nobs: Number of observed data points in the binxmedian: Median x-value of the observed data points in the binxmean: Mean x-value of the observed data points in the binxmax: Maximum x-value of the observed data points in the binxmin: Minimum x-value of the observed data points in the binxmid: Value halfway between `xmin` and `xmax`. x-value of the observed data points in the binxleft: Value halfway between the minimum x-value of the current bin and the maximum x-value of the previous bin to the left (for the left-most bin, it is the minimum x-value).xright: Value halfway between the maximum x-value of the current bin and the minimum x-value of the next bin to the right (for the right-most bin, it is the maximum x-value).xcenter: Value halfway between `xleft` and `xright`.
In addition, if stratification was performed, the stratification columns will be included as well.