Compute prediction interval statistics for VPC.
Arguments
- o
A
tidyvpcobj.- ...
Other arguments to include.
- vpc.type
Character specifying type of VPC (e.g.,
"continuous"(Default) or"categorical").- qpred
Numeric vector of length 3 specifying quantile prediction interval. Only applicable for
vpc.type = "continuous".- conf.level
Numeric specifying confidence level.
- quantile.type
Numeric indicating quantile type. See
quantile.
Value
Updates tidyvpcobj with stats data.table object, which contains the following columns:
bin: Resulting bin value as specified inbinning()functionxbin: Midpoint x-value of the observed data points in the bin as specified inxbinargument ofbinning()functionqname: Quantiles specified inqpred. Only returned ifvpc.type = "continuous"pname: Categorical probability names. Only returned ifvpc.type = "categorical"y: Observed y value for the specified quantilelo: Lower bound of specified confidence interval for y value in simulated datamd: Median y value in simulated datahi: Upper bound of specified confidence interval for y value in simulated data