Obtain information about the bins from a VPC object.
bininfo(o, ...)# S3 method for tidyvpcobj
bininfo(o, by.strata = o$bin.by.strata, ...)
An object.
Additional arguments.
Should the calculations be done by strata? Defaults to what was specified when the binning was done.
A `data.table` containing the following columns:
nobs: the number of observed data points in the bin
xmedian: the median x-value of the observed data points in the bin
xmean: the mean x-value of the observed data points in the bin
xmax: the maximum x-value of the observed data points in the bin
xmin: the minimum x-value of the observed data points in the bin
xmid: the value halfway between `xmin` and `xmax`.
x-value of the observed data points in the bin
xleft: the value halfway between the minimum x-value of the
current bin and the maximum x-value of the previous bin to the left (for
the left-most bin it is the minimum x-value).
xright: the value halfway between the maximum x-value of the
current bin and the minimum x-value of the next bin to the right (for the
right-most bin it is the maximum x-value).
xcenter: the value halfway between `xleft` and `xright`.
In addition, if statification was performed, the stratification columns will be included as well.
tidyvpcobj: Method for tidyvpcobj.